@@ -49,9 +49,9 @@ class Client(Singleton):
         self.put_topic = 'fs_put'
         self.get_topic = 'fs_get'
 
-        mqtt_client = MQTTClient('fs_server', 'opush', 'innovation').connect('kafka.ai.hamuna.club', 1883)
-        mqtt_client.subscribe('fs_backend_update', 2)
-        mqtt_client.register_on_message_handler(self.__on_mqtt_message)
+        # mqtt_client = MQTTClient('fs_server', 'opush', 'innovation').connect('kafka.ai.hamuna.club', 1883)
+        # mqtt_client.subscribe('fs_backend_update', 2)
+        # mqtt_client.register_on_message_handler(self.__on_mqtt_message)
         
         self.update()
         self._inited = True
@@ -449,7 +449,7 @@ class Client(Singleton):
             return entrypoint
 
     async def cleanup_cloud(self):
-        for k, backend in self.backend_pools:
+        for k, backend in self.backend_pools.items():
             print('cleanup {} files'.format(k))
             await backend.cleanup_old_files()
                     
