@@ -1,3 +1,4 @@
+import asyncio
 import traceback
 from cv2 import trace
 import redis
@@ -290,6 +291,11 @@ class XRedisAsync(Singleton):
         self.locker = threading.Lock()
         pool = coredis.ConnectionPool(host=self.host, password=self.password, port=self.port, db=self.db, decode_responses=True, socket_keepalive=True, retry_on_timeout=True)
         self.conn = coredis.StrictRedis(connection_pool=pool)
+
+    async def _ping(self):
+        ret = await self.conn.ping()
+        if ret:
+            print('pinged')
             
     async def __release_conn(self):
         if hasattr(self, 'conn'):
@@ -327,7 +333,7 @@ class XRedisAsync(Singleton):
                 return await self._get_connection(pipeline, transaction)
         
         if pipeline:
-            return await conn.pipeline(transaction)
+            return conn.pipeline(transaction)
         else:
             return conn
 
@@ -341,7 +347,7 @@ class XRedisAsync(Singleton):
             return None
         except Exception as e:
             if tries < 3:
-                time.sleep(0.1)
+                await asyncio.sleep(0.1)
                 return await self.lock(lock_id, ttl, tries + 1)
             else:
                 traceback.print_exc()
@@ -355,7 +361,7 @@ class XRedisAsync(Singleton):
             return True
         except Exception as e:
             if tries < 3:
-                time.sleep(0.1)
+                await asyncio.sleep(0.1)
                 await self.set(key, val, expired, tries + 1)
             else:
                 traceback.print_exc()
